@@ -178,7 +178,7 @@ class domain(config_domain):
     # XXX ouch, verify this crap and add defaults and stuff
     _types = {
         'profile': 'ref:profile', 'fetcher': 'ref:fetcher',
-        'repos': 'lazy_refs:repo', 'vdb': 'lazy_refs:repo', 'name': 'str',
+        'repos': 'lazy_refs:repo', 'vdb': 'lazy_refs:repo',
     }
     for _thing in ('root', 'config_dir', 'CHOST', 'CBUILD', 'CTARGET', 'CFLAGS', 'PATH',
                    'PORTAGE_TMPDIR', 'DISTCC_PATH', 'DISTCC_DIR', 'CCACHE_DIR'):
@@ -187,15 +187,13 @@ class domain(config_domain):
     # TODO this is missing defaults
     pkgcore_config_type = ConfigHint(
         _types, typename='domain',
-        required=['repos', 'profile', 'vdb', 'fetcher', 'name'],
+        required=['repos', 'profile', 'vdb', 'fetcher'],
         allow_unknowns=True)
 
     del _types, _thing
 
-    def __init__(self, profile, repos, vdb, name=None,
-                 root='/', config_dir='/etc/portage', prefix='/', *,
-                 fetcher, **settings):
-        self.name = name
+    def __init__(self, profile, repos, vdb, root='/', prefix='/',
+                 config_dir='/etc/portage', *, fetcher, **settings):
         self.root = settings["ROOT"] = root
         self.config_dir = config_dir
         self.prefix = prefix
@@ -438,7 +436,7 @@ class domain(config_domain):
         for and_pair in pkg.license.dnf_solutions():
             accepted = incremental_expansion_license(
                 pkg, and_pair, license_manager.groups, raw_accepted_licenses,
-                msg_prefix=f"while checking ACCEPT_LICENSE ")
+                msg_prefix="while checking ACCEPT_LICENSE ")
             if accepted.issuperset(and_pair):
                 return True
         return False
@@ -467,7 +465,6 @@ class domain(config_domain):
 
         if incremental:
             raise NotImplementedError(self._incremental_apply_keywords_filter)
-            #f = self._incremental_apply_keywords_filter
         else:
             f = self._apply_keywords_filter
         return delegate(partial(f, data))
@@ -678,22 +675,22 @@ class domain(config_domain):
     def _configure_repo(self, repo):
         """Configure a raw repo."""
         if not repo.configured:
-            pargs = [repo]
+            args = []
             try:
                 for x in repo.configurables:
                     if x == "domain":
-                        pargs.append(self)
+                        args.append(self)
                     elif x == "settings":
-                        pargs.append(self.settings)
+                        args.append(self.settings)
                     elif x == "profile":
-                        pargs.append(self.profile)
+                        args.append(self.profile)
                     else:
-                        pargs.append(getattr(self, x))
+                        args.append(getattr(self, x))
             except AttributeError as e:
                 raise Failure(
                     f"failed configuring repo {repo!r}: "
                     f"configurable missing: {e}") from e
-            repo = repo.configure(*pargs)
+            repo = repo.configure(*args)
         return repo
 
     def filter_repo(self, repo, pkg_masks=None, pkg_unmasks=None, pkg_filters=None,
