@@ -10,6 +10,7 @@ __all__ = (
 import configparser
 import errno
 import os
+import sys
 from collections import OrderedDict
 
 from snakeoil.bash import read_bash_dict
@@ -98,7 +99,6 @@ class PortageConfig(DictMixin):
                 (defaults to /etc/portage)
             profile_override (optional[str]): profile to use instead of the current system
                 profile, i.e. the target of the /etc/portage/make.profile symlink
-            configroot (optional[str]): location for various portage config files (defaults to /)
             root (optional[str]): target root filesystem (defaults to /)
             buildpkg (optional[bool]): forcibly disable/enable building binpkgs, otherwise
                 FEATURES=buildpkg from make.conf is used
@@ -107,20 +107,25 @@ class PortageConfig(DictMixin):
             dict: config settings
         """
         self._config = {}
+        stubconfig = pjoin(const.DATA_PATH, 'stubconfig')
 
         if location is None:
-            location = '/etc/portage'
-            # fallback to stub config and profile on non-Gentoo systems
-            if not os.path.exists(location):
-                location = pjoin(const.DATA_PATH, 'stubconfig')
-                profile_override = pjoin(const.DATA_PATH, 'stubrepo/profiles/default')
-        elif location == pjoin(const.DATA_PATH, 'stubconfig'):
-            # override profile when using stub config
+            path = os.path.abspath(sys.prefix)
+            while (parent := os.path.dirname(path)) != path:
+                config_root = pjoin(parent, 'etc/portage')
+                if os.path.exists(config_root):
+                    location = config_root
+                    break
+                path = parent
+            else:
+                # fallback to stub config non-Gentoo systems
+                location = stubconfig
+
+        # override profile when using stub config
+        if location == stubconfig:
             profile_override = pjoin(const.DATA_PATH, 'stubrepo/profiles/default')
 
-        self.dir = pjoin(
-            os.environ.get('PORTAGE_CONFIGROOT', kwargs.pop('configroot', '/')),
-            location.lstrip('/'))
+        self.dir = location
 
         # this actually differs from portage parsing- we allow
         # make.globals to provide vars used in make.conf, portage keeps
@@ -177,6 +182,7 @@ class PortageConfig(DictMixin):
         })
 
         repo_map = {}
+        repos = []
 
         for repo_name, repo_opts in list(repos_conf.items()):
             repo_cls = repo_opts.pop('repo-type')
@@ -190,14 +196,16 @@ class PortageConfig(DictMixin):
                 del repos_conf[repo_name]
                 continue
 
-            self[repo_name] = basics.AutoConfigSection(repo)
+            # only register existent repos
+            if os.path.exists(repo_opts['location']):
+                self[repo_name] = basics.AutoConfigSection(repo)
+                repos.append(repo_name)
 
         # XXX: Hack for portage-2 profile format support. We need to figure out how
         # to dynamically create this from the config at runtime on attr access.
         profiles.ProfileNode._repo_map = ImmutableDict(repo_map)
 
         self._make_repo_syncers(repos_conf, make_conf)
-        repos = [name for name in repos_conf.keys()]
         if repos:
             self['repo-stack'] = basics.FakeIncrementalDictConfigSection(
                 my_convert_hybrid, {
@@ -229,7 +237,6 @@ class PortageConfig(DictMixin):
             'default': True,
             'vdb': ('vdb',),
             'profile': 'profile',
-            'name': 'livefs',
             'root': self.root,
             'config_dir': self.dir,
         })
@@ -510,7 +517,7 @@ class PortageConfig(DictMixin):
 
         fetcher_dict = {
             "class": "pkgcore.fetch.custom.fetcher",
-            "distdir": os.path.normpath(os.environ.get("DISTDIR", make_conf.pop("DISTDIR"))),
+            "distdir": os.path.normpath(make_conf.pop("DISTDIR")),
             "command": fetchcommand,
             "resume_command": resumecommand,
             "attempts": make_conf.pop("FETCH_ATTEMPTS", '10'),
