@@ -6,91 +6,64 @@ __all__ = ("UnconfiguredTree", "ConfiguredTree", "ProvidesRepo", "tree")
 
 import locale
 import os
-import stat
 from functools import partial, wraps
 from itertools import chain, filterfalse
-from operator import attrgetter
 from random import shuffle
 from sys import intern
 from weakref import WeakValueDictionary
 
 from snakeoil import chksum, klass
-from snakeoil.bash import iter_read_bash, read_dict
+from snakeoil.bash import read_dict
 from snakeoil.containers import InvertedContains
 from snakeoil.data_source import local_source
-from snakeoil.fileutils import readlines
 from snakeoil.mappings import ImmutableDict
 from snakeoil.obj import make_kls
 from snakeoil.osutils import listdir_dirs, listdir_files, pjoin
 from snakeoil.sequences import iflatten_instance, stable_unique
-from snakeoil.strings import pluralism as _pl
+from snakeoil.strings import pluralism
 
 from .. import fetch
 from ..config.hint import ConfigHint, configurable
-from ..fs.livefs import sorted_scan
 from ..log import logger
 from ..operations import repo as _repo_ops
 from ..package import errors as pkg_errors
 from ..repository import configured, errors, prototype, util
 from ..repository.virtual import RestrictionRepo
 from ..restrictions import packages
-from ..util.packages import groupby_pkg
-from . import atom, cpv, digest, ebd, ebuild_src
+from ..util import packages as pkgutils
+from . import cpv, digest, ebd, ebuild_src
 from . import eclass_cache as eclass_cache_mod
-from . import errors as ebuild_errors
 from . import processor, repo_objs, restricts
 from .eapi import get_eapi
 
 
 class repo_operations(_repo_ops.operations):
 
-    def _cmd_implementation_digests(self, domain, matches, observer,
-                                    mirrors=False, force=False):
+    def _cmd_implementation_manifest(self, domain, restriction, observer,
+                                     mirrors=False, force=False):
         manifest_config = self.repo.config.manifests
         if manifest_config.disabled:
-            observer.info(f"repo {self.repo.repo_id} has manifests disabled")
+            observer.info(f'{self.repo.repo_id} repo has manifests disabled')
             return
         required_chksums = set(manifest_config.required_hashes)
         write_chksums = manifest_config.hashes
         distdir = domain.fetcher.distdir
         ret = set()
 
-        for key_query in sorted(set(match.unversioned_atom for match in matches)):
-            pkgs = self.repo.match(key_query)
+        matches = self.repo.itermatch(restriction, sorter=sorted)
+        for pkgs in map(list, pkgutils.groupby_pkg(matches)):
+            key = pkgs[0].key
+            manifest = pkgs[0].manifest
 
             # check for pkgs masked by bad metadata
-            bad_metadata = self.repo._bad_masked.match(key_query)
-            if bad_metadata:
+            if bad_metadata := self.repo._bad_masked.match(pkgs[0].unversioned_atom):
                 for pkg in bad_metadata:
                     e = pkg.data
                     error_str = f"{pkg.cpvstr}: {e.msg(verbosity=observer.verbosity)}"
                     observer.error(error_str)
-                    ret.add(key_query)
+                    ret.add(pkg.key)
                 continue
 
-            # Check for bad ebuilds -- mismatched or invalid PNs won't be
-            # matched by regular restrictions so they will otherwise be
-            # ignored.
-            ebuilds = {
-                x for x in listdir_files(pjoin(self.repo.location, str(key_query)))
-                if x.endswith('.ebuild')
-            }
-            unknown_ebuilds = ebuilds.difference(os.path.basename(x.path) for x in pkgs)
-            if unknown_ebuilds:
-                error_str = (
-                    f"{key_query}: invalid ebuild{_pl(unknown_ebuilds)}: "
-                    f"{', '.join(unknown_ebuilds)}"
-                )
-                observer.error(error_str)
-                ret.add(key_query)
-                continue
-
-            # empty package dir
-            if not pkgs:
-                continue
-
-            manifest = pkgs[0].manifest
-
             # all pkgdir fetchables
             pkgdir_fetchables = {}
             for pkg in pkgs:
@@ -119,23 +92,23 @@ class repo_operations(_repo_ops.operations):
                     except EnvironmentError as e:
                         observer.error(
                             'failed removing old manifest: '
-                            f'{key_query}::{self.repo.repo_id}: {e}')
-                        ret.add(key_query)
+                            f'{key}::{self.repo.repo_id}: {e}')
+                        ret.add(key)
                 continue
 
             # Manifest file is current and not forcing a refresh
             if not force and manifest.distfiles.keys() == pkgdir_fetchables.keys():
                 continue
 
-            pkg_ops = domain.pkg_operations(pkgs[0], observer=observer)
+            pkg_ops = domain.pkg_operations(pkg, observer=observer)
             if not pkg_ops.supports("fetch"):
-                observer.error(f"pkg {pkg} doesn't support fetching, can't generate manifest")
-                ret.add(key_query)
+                observer.error(f"{key}: fetching unsupported, can't generate manifest")
+                ret.add(key)
                 continue
 
             # fetch distfiles
             if not pkg_ops.fetch(list(fetchables.values()), observer):
-                ret.add(key_query)
+                ret.add(key)
                 continue
 
             # calculate checksums for fetched distfiles
@@ -146,12 +119,12 @@ class repo_operations(_repo_ops.operations):
                     fetchable.chksums = dict(zip(write_chksums, chksums))
             except chksum.MissingChksumHandler as e:
                 observer.error(f'failed generating chksum: {e}')
-                ret.add(key_query)
+                ret.add(key)
                 break
 
-            if key_query not in ret:
+            if key not in ret:
                 fetchables.update(pkgdir_fetchables)
-                observer.info(f"generating manifest: {key_query}::{self.repo.repo_id}")
+                observer.info(f"generating manifest: {key}::{self.repo.repo_id}")
                 manifest.update(sorted(fetchables.values()), chfs=write_chksums)
 
         return ret
@@ -250,13 +223,9 @@ class UnconfiguredTree(prototype.tree):
     Return packages don't have USE configuration bound to them.
     """
 
-    false_packages = frozenset(["CVS", ".svn"])
-    false_categories = frozenset([
-        "eclass", "profiles", "packages", "distfiles", "metadata",
-        "licenses", "scripts", "CVS", "local"])
+    false_categories = frozenset(["eclass", "profiles", "metadata", "licenses"])
     configured = False
     configurables = ("domain", "settings")
-    configure = None
     package_factory = staticmethod(ebuild_src.generate_new_factory)
     enable_gpg = False
     extension = '.ebuild'
@@ -349,6 +318,9 @@ class UnconfiguredTree(prototype.tree):
     external = klass.alias_attr('config.external')
     pkg_masks = klass.alias_attr('config.pkg_masks')
 
+    def configure(self, *args):
+        return ConfiguredTree(self, *args)
+
     @klass.jit_attr
     def known_arches(self):
         """Return all known arches for a repo (including masters)."""
@@ -451,8 +423,7 @@ class UnconfiguredTree(prototype.tree):
     def _get_packages(self, category):
         cpath = pjoin(self.base, category.lstrip(os.path.sep))
         try:
-            return tuple(filterfalse(
-                self.false_packages.__contains__, listdir_dirs(cpath)))
+            return tuple(listdir_dirs(cpath))
         except FileNotFoundError:
             if category in self.categories:
                 # ignore it, since it's PMS mandated that it be allowed.
@@ -690,10 +661,10 @@ class ConfiguredTree(configured.tree):
             for getting access to fetchable files
         """
         required_settings = {'USE', 'CHOST'}
-        missing_settings = required_settings.difference(domain_settings)
-        if missing_settings:
+        if missing_settings := required_settings.difference(domain_settings):
+            s = pluralism(missing_settings)
             raise errors.InitializationError(
-                f"{self.__class__} missing required setting{_pl(missing_settings)}: "
+                f"{self.__class__} missing required setting{s}: "
                 f"{', '.join(map(repr, missing_settings))}")
 
         chost = domain_settings['CHOST']
@@ -781,6 +752,3 @@ class ConfiguredTree(configured.tree):
             fetcher = domain.fetcher
         return ebd.src_operations(
             domain, pkg, pkg.repo.eclass_cache, fetcher=fetcher, **kwds)
-
-
-UnconfiguredTree.configure = ConfiguredTree
