@@ -11,7 +11,7 @@ from snakeoil.mappings import IndeterminantDict
 from snakeoil.osutils import listdir_dirs, pjoin
 
 from ..config.hint import ConfigHint
-from ..ebuild import ebuild_built
+from ..ebuild import ebd, ebuild_built
 from ..ebuild.cpv import VersionedCPV
 from ..ebuild.errors import InvalidCPV
 from ..log import logger
@@ -27,7 +27,6 @@ class tree(prototype.tree):
     livefs = True
     configured = False
     configurables = ("domain", "settings")
-    configure = None
     package_factory = staticmethod(ebuild_built.generate_new_factory)
     operations_kls = repo_ops.operations
 
@@ -53,7 +52,7 @@ class tree(prototype.tree):
             if not stat.S_ISDIR(st.st_mode):
                 raise errors.InitializationError(
                     f"base not a dir: {self.location!r}")
-            elif not st.st_mode & (os.X_OK|os.R_OK):
+            elif not st.st_mode & (os.X_OK | os.R_OK):
                 raise errors.InitializationError(
                     f"base lacks read/executable: {self.location!r}")
         except FileNotFoundError:
@@ -63,6 +62,9 @@ class tree(prototype.tree):
 
         self.package_class = self.package_factory(self)
 
+    def configure(self, *args):
+        return ConfiguredTree(self, *args)
+
     def _get_categories(self, *optional_category):
         # return if optional_category is passed... cause it's not yet supported
         if optional_category:
@@ -219,6 +221,3 @@ class ConfiguredTree(wrapper.tree, tree):
         pkg = pkg._raw_pkg
         return ebd.built_operations(
             domain, pkg, initial_env=self.domain_settings, **kwargs)
-
-
-tree.configure = ConfiguredTree
